==> rc-ui-lib-0.1.29.tgz: package/es/tabs/TabPane.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, useContext, useMemo, forwardRef } from 'react';
import classnames from 'classnames';
import TabsContext from './TabsContext';
import { createNamespace } from '../utils';
import { useUpdateEffect } from '../hooks';

var _createNamespace = createNamespace('tab'),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];

var TabPane = /*#__PURE__*/forwardRef(function (props, ref) {
  var parent = useContext(TabsContext);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      inited = _useState2[0],
      setInited = _useState2[1];

  var _parent$props = parent.props,
      animated = _parent$props.animated,
      swipeable = _parent$props.swipeable,
      scrollspy = _parent$props.scrollspy,
      lazyRender = _parent$props.lazyRender;
  var index = props.index;

  var getName = function getName() {
    var _props$name;

    return (_props$name = props.name) !== null && _props$name !== void 0 ? _props$name : index;
  };

  var init = function init() {
    setInited(true);
  };

  var isActive = useMemo(function () {
    var active = getName() === parent.currentName;

    if (active && !inited) {
      init();
    }

    return active;
  }, [inited, parent.currentName]);
  useUpdateEffect(function () {
    parent.setLine();
    parent.scrollIntoView();
  }, [props.title]);
  var show = scrollspy || isActive;

  if (animated || swipeable) {
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('pane'))
    }, props.children);
  }

  var shouldRender = inited || scrollspy || !lazyRender;
  var Content = shouldRender ? props.children : null;
  return /*#__PURE__*/React.createElement("div", {
    ref: ref,
    style: {
      display: show ? 'block' : 'none'
    },
    role: "tabpanel",
    className: classnames(bem('pane'))
  }, Content);
});
TabPane.defaultProps = {
  showZeroBadge: true
};
export default TabPane;

==> rc-ui-lib-0.1.41.tgz: package/es/tabs/TabPane.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, useContext, useMemo, forwardRef } from 'react';
import classnames from 'classnames';
import TabsContext from './TabsContext';
import { useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var TabPane = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('tab', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var parent = useContext(TabsContext);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      inited = _useState2[0],
      setInited = _useState2[1];

  var _parent$props = parent.props,
      animated = _parent$props.animated,
      swipeable = _parent$props.swipeable,
      scrollspy = _parent$props.scrollspy,
      lazyRender = _parent$props.lazyRender;
  var index = props.index;

  var getName = function getName() {
    var _props$name;

    return (_props$name = props.name) !== null && _props$name !== void 0 ? _props$name : index;
  };

  var init = function init() {
    setInited(true);
  };

  var isActive = useMemo(function () {
    var active = getName() === parent.currentName;

    if (active && !inited) {
      init();
    }

    return active;
  }, [inited, parent.currentName]);
  useUpdateEffect(function () {
    parent.setLine();
    parent.scrollIntoView();
  }, [props.title]);
  var show = scrollspy || isActive;

  if (animated || swipeable) {
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('pane'))
    }, props.children);
  }

  var shouldRender = inited || scrollspy || !lazyRender;
  var Content = shouldRender ? props.children : null;
  return /*#__PURE__*/React.createElement("div", {
    ref: ref,
    style: {
      display: show ? 'block' : 'none'
    },
    role: "tabpanel",
    className: classnames(bem('pane'))
  }, Content);
});
TabPane.defaultProps = {
  showZeroBadge: true
};
export default TabPane;
